@@ -1,6 +1,5 @@
 
 import codecs
-import getopt
 import glob
 import os
 import pprint
@@ -13,13 +12,15 @@ except ImportError:  # PY3
     import pickle as pickle
 from optparse import OptionParser
 
-from Cheetah.Version import Version
-from Cheetah.Template import Template, DEFAULT_COMPILER_SETTINGS
+from Cheetah.Compiler import DEFAULT_COMPILER_SETTINGS
+from Cheetah.Template import Template
 from Cheetah.Utils.Misc import mkdirsWithPyInitFiles
+from Cheetah.Version import Version
 from Cheetah.compat import PY2
 
-optionDashesRE = re.compile(  R"^-{1,2}"  )
-moduleNameRE = re.compile(  R"^[a-zA-Z_][a-zA-Z_0-9]*$"  )
+optionDashesRE = re.compile(R"^-{1,2}")
+moduleNameRE = re.compile(R"^[a-zA-Z_][a-zA-Z_0-9]*$")
+
 
 def fprintfMessage(stream, format, *args):
     if format[-1:] == '^':
@@ -32,6 +33,7 @@ def fprintfMessage(stream, format, *args):
         message = format
     stream.write(message)
 
+
 class Error(Exception):
     pass
 
@@ -48,7 +50,7 @@ class Bundle:
 
 
 ##################################################
-## USAGE FUNCTION & MESSAGES
+# USAGE FUNCTION & MESSAGES
 
 def usage(usageMessage, errorMessage="", out=sys.stderr):
     """Write help text, an optional error message, and abort the program.
@@ -91,7 +93,8 @@ Run "cheetah options" for the list of valid options.
 """
 
 ##################################################
-## CheetahWrapper CLASS
+# CheetahWrapper CLASS
+
 
 class CheetahWrapper(object):
     MAKE_BACKUPS = True
@@ -109,7 +112,7 @@ class CheetahWrapper(object):
         self.parser = None
 
     ##################################################
-    ## MAIN ROUTINE
+    # MAIN ROUTINE
 
     def main(self, argv=None):
         """The main program controller."""
@@ -119,7 +122,7 @@ class CheetahWrapper(object):
 
         # Step 1: Determine the command and arguments.
         try:
-            self.progName = progName = os.path.basename(argv[0])
+            self.progName = os.path.basename(argv[0])
             self.command = command = optionDashesRE.sub("", argv[1])
             if command == 'test':
                 self.testOpts = argv[2:]
@@ -130,7 +133,7 @@ class CheetahWrapper(object):
 
         # Step 2: Call the command
         meths = (self.compile, self.fill, self.help, self.options,
-            self.test, self.version)
+                 self.test, self.version)
         for meth in meths:
             methName = meth.__name__
             # Or meth.__func__.__name__
@@ -146,29 +149,57 @@ class CheetahWrapper(object):
         usage(HELP_PAGE1, "unknown command '%s'" % command)
 
     def parseOpts(self, args):
-        C, D, W = self.chatter, self.debug, self.warn
+        D = self.debug
         self.isCompile = isCompile = self.command[0] == 'c'
         defaultOext = isCompile and ".py" or ".html"
         self.parser = OptionParser()
         pao = self.parser.add_option
-        pao("--idir", action="store", dest="idir", default='', help='Input directory (defaults to current directory)')
-        pao("--odir", action="store", dest="odir", default="", help='Output directory (defaults to current directory)')
-        pao("--iext", action="store", dest="iext", default=".tmpl", help='File input extension (defaults: compile: .tmpl, fill: .tmpl)')
-        pao("--oext", action="store", dest="oext", default=defaultOext, help='File output extension (defaults: compile: .py, fill: .html)')
-        pao("-R", action="store_true", dest="recurse", default=False, help='Recurse through subdirectories looking for input files')
-        pao("--stdout", "-p", action="store_true", dest="stdout", default=False, help='Send output to stdout instead of writing to a file')
-        pao("--quiet", action="store_false", dest="verbose", default=True, help='Do not print informational messages to stdout')
-        pao("--debug", action="store_true", dest="debug", default=False, help='Print diagnostic/debug information to stderr')
-        pao("--env", action="store_true", dest="env", default=False, help='Pass the environment into the search list')
-        pao("--pickle", action="store", dest="pickle", default="", help='Unpickle FILE and pass it through in the search list')
-        pao("--flat", action="store_true", dest="flat", default=False, help='Do not build destination subdirectories')
-        pao("--nobackup", action="store_true", dest="nobackup", default=False, help='Do not make backup files when generating new ones')
-        pao("--settings", action="store", dest="compilerSettingsString", default=None, help='String of compiler settings to pass through, e.g. --settings="useNameMapper=False,useFilters=False"')
-        pao('--print-settings', action='store_true', dest='print_settings', help='Print out the list of available compiler settings')
-        pao("--templateAPIClass", action="store", dest="templateClassName", default=None, help='Name of a subclass of Cheetah.Template.Template to use for compilation, e.g. MyTemplateClass')
-        pao("--parallel", action="store", type="int", dest="parallel", default=1, help='Compile/fill templates in parallel, e.g. --parallel=4')
-        pao('--shbang', dest='shbang', default='#!/usr/bin/env python', help='Specify the shbang to place at the top of compiled templates, e.g. --shbang="#!/usr/bin/python2.6"')
-        pao('--encoding', dest='encoding', default=None, help='Specify the encoding of source files (e.g. \'utf-8\' to force input files to be interpreted as UTF-8)')
+        pao("--idir", action="store", dest="idir", default='',
+            help='Input directory (defaults to current directory)')
+        pao("--odir", action="store", dest="odir", default="",
+            help='Output directory (defaults to current directory)')
+        pao("--iext", action="store", dest="iext", default=".tmpl",
+            help='File input extension '
+                 '(defaults: compile: .tmpl, fill: .tmpl)')
+        pao("--oext", action="store", dest="oext", default=defaultOext,
+            help='File output extension (defaults: compile: .py, fill: .html)')
+        pao("-R", action="store_true", dest="recurse", default=False,
+            help='Recurse through subdirectories looking for input files')
+        pao("--stdout", "-p", action="store_true", dest="stdout",
+            default=False,
+            help='Send output to stdout instead of writing to a file')
+        pao("--quiet", action="store_false", dest="verbose", default=True,
+            help='Do not print informational messages to stdout')
+        pao("--debug", action="store_true", dest="debug", default=False,
+            help='Print diagnostic/debug information to stderr')
+        pao("--env", action="store_true", dest="env", default=False,
+            help='Pass the environment into the search list')
+        pao("--pickle", action="store", dest="pickle", default="",
+            help='Unpickle FILE and pass it through in the search list')
+        pao("--flat", action="store_true", dest="flat", default=False,
+            help='Do not build destination subdirectories')
+        pao("--nobackup", action="store_true", dest="nobackup", default=False,
+            help='Do not make backup files when generating new ones')
+        pao("--settings", action="store", dest="compilerSettingsString",
+            default=None,
+            help='String of compiler settings to pass through, '
+                 'e.g. --settings="useNameMapper=False,useFilters=False"')
+        pao('--print-settings', action='store_true', dest='print_settings',
+            help='Print out the list of available compiler settings')
+        pao("--templateAPIClass", action="store", dest="templateClassName",
+            default=None,
+            help='Name of a subclass of Cheetah.Template.Template '
+                 'to use for compilation, e.g. MyTemplateClass')
+        pao("--parallel", action="store", type="int", dest="parallel",
+            default=1,
+            help='Compile/fill templates in parallel, e.g. --parallel=4')
+        pao('--shbang', dest='shbang', default='#!/usr/bin/env python',
+            help='Specify the shbang to place at the top '
+                 'of compiled templates, e.g. --shbang="#!/usr/bin/python2.6"')
+        pao('--encoding', dest='encoding', default=None,
+            help='Specify the encoding of source files '
+                 '(e.g. "utf-8" to force input files to be interpreted '
+                 'as UTF-8)')
 
         opts, files = self.parser.parse_args(args)
         self.opts = opts
@@ -189,7 +220,6 @@ Options are
 %s
 Files are %s""", args, pprint.pformat(vars(opts)), files)
 
-
         if opts.print_settings:
             print()
             print('>> Available Cheetah compiler settings:')
@@ -201,7 +231,7 @@ Files are %s""", args, pprint.pformat(vars(opts)), files)
                 print('\t%s (default: "%s")\t%s' % l)
             sys.exit(0)
 
-        #cleanup trailing path separators
+        # cleanup trailing path separators
         seps = [sep for sep in [os.sep, os.altsep] if sep]
         for attr in ['idir', 'odir']:
             for sep in seps:
@@ -221,7 +251,7 @@ Files are %s""", args, pprint.pformat(vars(opts)), files)
             self.searchList.insert(0, unpickled)
 
     ##################################################
-    ## COMMAND METHODS
+    # COMMAND METHODS
 
     def compile(self):
         self._compileOrFill()
@@ -242,7 +272,7 @@ Files are %s""", args, pprint.pformat(vars(opts)), files)
         TEST_WRITE_FILENAME = 'cheetah_test_file_creation_ability.tmp'
         try:
             f = open(TEST_WRITE_FILENAME, 'w')
-        except:
+        except Exception:
             sys.exit("""\
 Cannot run the tests because you don't have write permission in the current
 directory.  The tests need to create temporary files.  Change to a directory
@@ -268,7 +298,7 @@ you do have write permission to and re-run the tests.""")
 
     # If you add a command, also add it to the 'meths' variable in main().
     ##################################################
-    ## LOGGING METHODS
+    # LOGGING METHODS
 
     def chatter(self, format, *args):
         """Print a verbose message to stdout.  But don't if .opts.stdout is
@@ -278,7 +308,6 @@ you do have write permission to and re-run the tests.""")
             return
         fprintfMessage(sys.stdout, format, *args)
 
-
     def debug(self, format, *args):
         """Print a debugging message to stderr, but don't if .debug is
            false.
@@ -298,8 +327,7 @@ you do have write permission to and re-run the tests.""")
         sys.exit(1)
 
     ##################################################
-    ## HELPER METHODS
-
+    # HELPER METHODS
 
     def _fixExts(self):
         assert self.opts.oext, "oext is empty!"
@@ -309,10 +337,8 @@ you do have write permission to and re-run the tests.""")
         if oext and not oext.startswith("."):
             self.opts.oext = "." + oext
 
-
-
     def _compileOrFill(self):
-        C, D, W = self.chatter, self.debug, self.warn
+        C, D = self.chatter, self.debug
         opts, files = self.opts, self.pathArgs
         if files == ["-"]:
             self._compileOrFillStdin()
@@ -375,7 +401,8 @@ you do have write permission to and re-run the tests.""")
                     bad_child_exit = child_exit
 
             if bad_child_exit:
-                sys.exit("Child process failed, exited with code %d" % bad_child_exit)
+                sys.exit("Child process failed, exited with code %d"
+                         % bad_child_exit)
 
         else:
             for b in bundles:
@@ -385,7 +412,7 @@ you do have write permission to and re-run the tests.""")
         """Check for multiple source paths writing to the same destination
            path.
         """
-        C, D, W = self.chatter, self.debug, self.warn
+        W = self.warn
         isError = False
         dstSources = {}
         for b in bundles:
@@ -399,18 +426,18 @@ you do have write permission to and re-run the tests.""")
             if len(sources) > 1:
                 isError = True
                 sources.sort()
-                fmt = "Collision: multiple source files %s map to one destination file %s"
+                fmt = "Collision: multiple source files %s " \
+                      "map to one destination file %s"
                 W(fmt, sources, dst)
         if isError:
             what = self.isCompile and "Compilation" or "Filling"
             sys.exit("%s aborted due to collisions" % what)
 
-
     def _expandSourceFiles(self, files, recurse, addIextIfMissing):
         """Calculate source paths from 'files' by applying the
            command-line options.
         """
-        C, D, W = self.chatter, self.debug, self.warn
+        D, W = self.debug, self.warn
         idir = self.opts.idir
         iext = self.opts.iext
         files = []
@@ -418,7 +445,7 @@ you do have write permission to and re-run the tests.""")
             oldFilesLen = len(files)
             D("Expanding %s", f)
             path = os.path.join(idir, f)
-            pathWithExt = path + iext # May or may not be valid.
+            pathWithExt = path + iext  # May or may not be valid.
             if os.path.isdir(path):
                 if recurse:
                     for root, dirs, _files in os.walk(path):
@@ -430,8 +457,8 @@ you do have write permission to and re-run the tests.""")
                     raise Error("source file '%s' is a directory" % path)
             elif os.path.isfile(path):
                 files.append(path)
-            elif (addIextIfMissing and not path.endswith(iext) and
-                  os.path.isfile(pathWithExt)):
+            elif (addIextIfMissing and not path.endswith(iext)
+                    and os.path.isfile(pathWithExt)):
                 files.append(pathWithExt)
                 # Do not recurse directories discovered by iext appending.
             elif os.path.exists(path):
@@ -442,12 +469,10 @@ you do have write permission to and re-run the tests.""")
                 D("  ... found %s", files[oldFilesLen:])
         return files
 
-
     def _getBundles(self, sourceFiles):
         flat = self.opts.flat
         idir = self.opts.idir
         iext = self.opts.iext
-        nobackup = self.opts.nobackup
         odir = self.opts.odir
         oext = self.opts.oext
         idirSlash = idir + os.sep
@@ -484,9 +509,8 @@ you do have write permission to and re-run the tests.""")
             bundles.append(b)
         return bundles
 
-
     def _getTemplateClass(self):
-        C, D, W = self.chatter, self.debug, self.warn
+        C = self.chatter
         modname = None
         if self._templateClass:
             return self._templateClass
@@ -503,10 +527,12 @@ you do have write permission to and re-run the tests.""")
 
         modname, classname = modname.split(':')
 
-        C('using --templateAPIClass=%s:%s'%(modname, classname))
+        C('using --templateAPIClass=%s:%s' % (modname, classname))
 
         if p >= 0:
-            mod = getattr(__import__(modname[:p], {}, {}, [modname[p+1:]]), modname[p+1:])
+            mod = getattr(
+                __import__(modname[:p], {}, {}, [modname[p+1:]]),  # noqa: E226,E501 missing whitespace around operator
+                modname[p+1:])  # noqa: E226 missing whitespace around operator
         else:
             mod = __import__(modname, {}, {}, [])
 
@@ -515,10 +541,10 @@ you do have write permission to and re-run the tests.""")
             self._templateClass = klass
             return klass
         else:
-            self.error('**Template class specified in option --templateAPIClass not found\n'
+            self.error('**Template class specified '
+                       'in option --templateAPIClass not found\n'
                        '**Falling back on Cheetah.Template:Template')
 
-
     def _getCompilerSettings(self):
         if self._compilerSettings:
             return self._compilerSettings
@@ -527,18 +553,23 @@ you do have write permission to and re-run the tests.""")
             return kws
         if self.opts.compilerSettingsString:
             try:
-                settings = eval('getkws(%s)'%self.opts.compilerSettingsString)
-            except:
+                settings = eval('getkws(%s)'
+                                % self.opts.compilerSettingsString)
+            except Exception:
                 self.error("There's an error in your --settings option."
-                          "It must be valid Python syntax.\n"
-                          +"    --settings='%s'\n"%self.opts.compilerSettingsString
-                          +"  %s: %s"%sys.exc_info()[:2]
-                          )
+                           "It must be valid Python syntax.\n"
+                           + "    --settings='%s'\n"
+                           % self.opts.compilerSettingsString
+                           + "  %s: %s" % sys.exc_info()[:2]
+                           )
 
             validKeys = set(DEFAULT_COMPILER_SETTINGS.keys())
-            if [k for k in settings if k not in validKeys]:
-                self.error(
-                    'The --setting "%s" is not a valid compiler setting name.'%k)
+            for k in settings:
+                if k not in validKeys:
+                    self.error(
+                        'The --setting "%s" '
+                        'is not a valid compiler setting name.'
+                        % k)
 
             self._compilerSettings = settings
             return settings
@@ -554,23 +585,23 @@ you do have write permission to and re-run the tests.""")
                                           returnAClass=False)
             output = pysrc
         else:
-            output = str(TemplateClass(file=sys.stdin, compilerSettings=compilerSettings))
+            output = str(TemplateClass(file=sys.stdin,
+                                       compilerSettings=compilerSettings))
         sys.stdout.write(output)
 
     def _compileOrFillBundle(self, b):
-        C, D, W = self.chatter, self.debug, self.warn
+        C = self.chatter
         TemplateClass = self._getTemplateClass()
         compilerSettings = self._getCompilerSettings()
         src = b.src
         dst = b.dst
-        base = b.base
         basename = b.basename
         dstDir = os.path.dirname(dst)
         what = self.isCompile and "Compiling" or "Filling"
-        C("%s %s -> %s^", what, src, dst) # No trailing newline.
+        C("%s %s -> %s^", what, src, dst)  # No trailing newline.
         if os.path.exists(dst) and not self.opts.nobackup:
             bak = b.bak
-            C(" (backup %s)", bak) # On same line as previous message.
+            C(" (backup %s)", bak)  # On same line as previous message.
         else:
             bak = None
             C("")
@@ -587,8 +618,9 @@ be named according to the same rules as Python modules.""" % tup)
                                           compilerSettings=compilerSettings)
             output = pysrc
         else:
-            #output = str(TemplateClass(file=src, searchList=self.searchList))
-            tclass = TemplateClass.compile(file=src, compilerSettings=compilerSettings)
+            # output = str(TemplateClass(file=src, searchList=self.searchList))
+            tclass = TemplateClass.compile(file=src,
+                                           compilerSettings=compilerSettings)
             output = str(tclass(searchList=self.searchList))
 
         if bak:
@@ -623,13 +655,14 @@ def _cheetah():
     CheetahWrapper().main()
 
 # Called when invoked as `cheetah-compile`
+
+
 def _cheetah_compile():
     sys.argv.insert(1, "compile")
     CheetahWrapper().main()
 
 
 ##################################################
-## if run from the command line
-if __name__ == '__main__':  CheetahWrapper().main()
-
-# vim: shiftwidth=4 tabstop=4 expandtab
+# if run from the command line
+if __name__ == '__main__':
+    CheetahWrapper().main()
