@@ -14,7 +14,6 @@ Besides unittest usage, recognizes the following command-line options:
 
 import os
 import os.path
-import pdb
 import re                                     # Used by listTests.
 import shutil
 import sys
@@ -26,13 +25,14 @@ from Cheetah.CheetahWrapper import CheetahWrapper  # Used by NoBackup.
 
 try:
     from subprocess import Popen, PIPE, STDOUT
+
     class Popen4(Popen):
         def __init__(self, cmd, bufsize=-1, shell=True, close_fds=True,
-                        stdin=PIPE, stdout=PIPE, stderr=STDOUT, **kwargs):
+                     stdin=PIPE, stdout=PIPE, stderr=STDOUT, **kwargs):
 
-            super(Popen4, self).__init__(cmd, bufsize=bufsize, shell=shell,
-                            close_fds=close_fds, stdin=stdin, stdout=stdout,
-                            stderr=stderr, **kwargs)
+            super(Popen4, self).__init__(
+                cmd, bufsize=bufsize, shell=shell, close_fds=close_fds,
+                stdin=stdin, stdout=stdout, stderr=stderr, **kwargs)
 
             self.tochild = self.stdin
             self.fromchild = self.stdout
@@ -40,21 +40,23 @@ try:
 except ImportError:
     from popen2 import Popen4
 
-DELETE = True # True to clean up after ourselves, False for debugging.
-OUTPUT = False # Normally False, True for debugging.
+DELETE = True  # True to clean up after ourselves, False for debugging.
+OUTPUT = False  # Normally False, True for debugging.
 
 BACKUP_SUFFIX = CheetahWrapper.BACKUP_SUFFIX
 
+
 def warn(msg):
     sys.stderr.write(msg + '\n')
 
+
 class CFBase(unittest.TestCase):
     """Base class for "cheetah compile" and "cheetah fill" unit tests.
     """
-    srcDir = '' # Nonblank to create source directory.
-    subdirs = ('child', 'child/grandkid') # Delete in reverse order.
+    srcDir = ''  # Nonblank to create source directory.
+    subdirs = ('child', 'child/grandkid')  # Delete in reverse order.
     srcFiles = ('a.tmpl', 'child/a.tmpl', 'child/grandkid/a.tmpl')
-    expectError = False # Used by --list option.
+    expectError = False  # Used by --list option.
 
     def inform(self, message):
         if self.verbose:
@@ -73,10 +75,8 @@ class CFBase(unittest.TestCase):
             if (pythonPath != cwd) and \
                     not pythonPath.endswith(':%s' % cwd):
                 os.environ['PYTHONPATH'] = '%s:%s' % (pythonPath, cwd)
-        I = self.inform
         # Step 1: Create the scratch directory and chdir into it.
-        self.scratchDir = scratchDir = tempfile.mktemp()
-        os.mkdir(scratchDir)
+        self.scratchDir = scratchDir = tempfile.mkdtemp()
         self.origCwd = os.getcwd()
         os.chdir(scratchDir)
         if self.srcDir:
@@ -93,15 +93,15 @@ class CFBase(unittest.TestCase):
     def tearDown(self):
         os.chdir(self.origCwd)
         if DELETE:
-            shutil.rmtree(self.scratchDir, True) # Ignore errors.
+            shutil.rmtree(self.scratchDir, True)  # Ignore errors.
             if os.path.exists(self.scratchDir):
                 warn("Warning: unable to delete scratch directory %s")
         else:
-            warn("Warning: not deleting scratch directory %s" % self.scratchDir)
-
+            warn("Warning: not deleting scratch directory %s"
+                 % self.scratchDir)
 
     def _checkDestFileHelper(self, path, expected,
-        allowSurroundingText, errmsg):
+                             allowSurroundingText, errmsg):
         """Low-level helper to check a destination file.
 
            in : path, string, the destination path.
@@ -126,17 +126,15 @@ class CFBase(unittest.TestCase):
         msg = errmsg % locals()
         self.assertTrue(success, msg)
 
-
     def checkCompile(self, path):
         # Raw string to prevent "\n" from being converted to a newline.
-        #expected = R"write('Hello, world!\n')"
-        expected = "Hello, world!" # might output a u'' string
+        # expected = R"write('Hello, world!\n')"
+        expected = "Hello, world!"  # might output a u'' string
         errmsg = """\
 destination file %(path)s doesn't contain expected substring:
 %(expected)r"""
         self._checkDestFileHelper(path, expected, True, errmsg)
 
-
     def checkFill(self, path):
         expected = "Hello, world!\n"
         errmsg = """\
@@ -145,7 +143,6 @@ Expected %(expected)r
 Found %(result)r"""
         self._checkDestFileHelper(path, expected, False, errmsg)
 
-
     def checkSubdirPyInit(self, path):
         """Verify a destination subdirectory exists and contains an
            __init__.py file.
@@ -158,7 +155,6 @@ Found %(result)r"""
         msg = "destination init file missing: %s" % initPath
         self.assertTrue(exists, msg)
 
-
     def checkNoBackup(self, path):
         """Verify 'path' does not exist.  (To check --nobackup.)
         """
@@ -170,7 +166,6 @@ Found %(result)r"""
         paths = os.getenv('PATH')
         if not paths:
             return cmd
-        parts = cmd.split(' ')
         paths = paths.split(':')
         for p in paths:
             p = os.path.join(p, cmd)
@@ -190,7 +185,8 @@ Found %(result)r"""
             if status is None:
                 status = 0
         else:
-            process = Popen(cmd, shell=True, stdin=PIPE, stdout=PIPE, stderr=STDOUT)
+            process = Popen(cmd, shell=True,
+                            stdin=PIPE, stdout=PIPE, stderr=STDOUT)
             process.stdin.close()
             output = process.stdout.read()
             status = process.wait()
@@ -244,13 +240,13 @@ class CFIdirBase(CFBase):
     """Subclass for tests with --idir.
     """
     srcDir = 'SRC'
-    subdirs = ('SRC/child', 'SRC/child/grandkid') # Delete in reverse order.
+    subdirs = ('SRC/child', 'SRC/child/grandkid')  # Delete in reverse order.
     srcFiles = ('SRC/a.tmpl', 'SRC/child/a.tmpl', 'SRC/child/grandkid/a.tmpl')
 
 
-
 ##################################################
-## TEST CASE CLASSES
+# TEST CASE CLASSES
+
 
 class OneFile(CFBase):
     def testCompile(self):
@@ -293,6 +289,7 @@ class SplatTmpl(CFBase):
         self.go("cheetah fill --oext txt *.tmpl")
         self.checkFill("a.txt")
 
+
 class ThreeFilesWithSubdirectories(CFBase):
     def testCompile(self):
         self.go("cheetah compile a.tmpl child/a.tmpl child/grandkid/a.tmpl")
@@ -307,7 +304,8 @@ class ThreeFilesWithSubdirectories(CFBase):
         self.checkFill("child/grandkid/a.html")
 
     def testText(self):
-        self.go("cheetah fill --oext txt a.tmpl child/a.tmpl child/grandkid/a.tmpl")
+        self.go("cheetah fill --oext txt "
+                "a.tmpl child/a.tmpl child/grandkid/a.tmpl")
         self.checkFill("a.txt")
         self.checkFill("child/a.txt")
         self.checkFill("child/grandkid/a.txt")
@@ -347,7 +345,8 @@ class SplatTmplWithSubdirectories(CFBase):
         self.checkFill("child/grandkid/a.html")
 
     def testText(self):
-        self.go("cheetah fill --oext txt *.tmpl child/*.tmpl child/grandkid/*.tmpl")
+        self.go("cheetah fill --oext txt "
+                "*.tmpl child/*.tmpl child/grandkid/*.tmpl")
         self.checkFill("a.txt")
         self.checkFill("child/a.txt")
         self.checkFill("child/grandkid/a.txt")
@@ -370,7 +369,8 @@ class OneFileWithOdir(CFBase):
 
 class VarietyWithOdir(CFBase):
     def testCompile(self):
-        self.go("cheetah compile --odir DEST a.tmpl child/a child/grandkid/*.tmpl")
+        self.go("cheetah compile --odir DEST "
+                "a.tmpl child/a child/grandkid/*.tmpl")
         self.checkSubdirPyInit("DEST")
         self.checkSubdirPyInit("DEST/child")
         self.checkSubdirPyInit("DEST/child/grandkid")
@@ -379,13 +379,15 @@ class VarietyWithOdir(CFBase):
         self.checkCompile("DEST/child/grandkid/a.py")
 
     def testFill(self):
-        self.go("cheetah fill --odir DEST a.tmpl child/a child/grandkid/*.tmpl")
+        self.go("cheetah fill --odir DEST "
+                "a.tmpl child/a child/grandkid/*.tmpl")
         self.checkFill("DEST/a.html")
         self.checkFill("DEST/child/a.html")
         self.checkFill("DEST/child/grandkid/a.html")
 
     def testText(self):
-        self.go("cheetah fill --odir DEST --oext txt a.tmpl child/a child/grandkid/*.tmpl")
+        self.go("cheetah fill --odir DEST --oext txt "
+                "a.tmpl child/a child/grandkid/*.tmpl")
         self.checkFill("DEST/a.txt")
         self.checkFill("DEST/child/a.txt")
         self.checkFill("DEST/child/grandkid/a.txt")
@@ -515,13 +517,16 @@ class IdirFlatRecurseCollision(CFIdirBase):
     expectError = True
 
     def testCompile(self):
-        self.assertSubprocess("cheetah compile -R --flat --idir SRC", nonzero=True)
+        self.assertSubprocess(
+            "cheetah compile -R --flat --idir SRC", nonzero=True)
 
     def testFill(self):
-        self.assertSubprocess("cheetah fill -R --flat --idir SRC", nonzero=True)
+        self.assertSubprocess(
+            "cheetah fill -R --flat --idir SRC", nonzero=True)
 
     def testText(self):
-        self.assertSubprocess("cheetah fill -R --flat --idir SRC --oext txt", nonzero=True)
+        self.assertSubprocess(
+            "cheetah fill -R --flat --idir SRC --oext txt", nonzero=True)
 
 
 class NoBackup(CFBase):
@@ -543,12 +548,13 @@ class NoBackup(CFBase):
         self.go("cheetah fill --nobackup --oext txt a.tmpl")
         self.checkNoBackup("a.txt" + BACKUP_SUFFIX)
 
+
 def listTests(cheetahWrapperFile):
     """cheetahWrapperFile, string, path of this script.
 
        XXX TODO: don't print test where expectError is true.
     """
-    rx = re.compile( R'self\.go\("(.*?)"\)' )
+    rx = re.compile(R'self\.go\("(.*?)"\)')
     f = open(cheetahWrapperFile)
     while True:
         lin = f.readline()
@@ -559,6 +565,7 @@ def listTests(cheetahWrapperFile):
             print(m.group(1))
     f.close()
 
+
 def main():
     global DELETE, OUTPUT
     parser = OptionParser()
@@ -586,6 +593,7 @@ def main():
         sys.argv.extend(files)
         unittest.main()
 
+
 if __name__ == '__main__':
     main()
 
